# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from ..CLI     import konsol
from flet.page import Page
from flet      import UserControl, GridView, Container, Column, Text, colors, border, ImageFit 
from ..Libs    import sondakika_haberleri, bildirim

class Haberler(UserControl):
    def __init__(self, sayfa:Page, panel:Page):
        super().__init__()
        self.sayfa = sayfa

        self.panel    = panel
        self.haberler = []
        self.__paneli_guncelle()

        self.haberler_grid = GridView(expand=True, width=550, child_aspect_ratio=1.3)
        self.haberleri_guncelle()


    def build(self):
        return Container(self.haberler_grid)

    def __haber_konteyner(self, veri:dict) -> Container:
        return Container(
            border        = border.all(width=2, color="#EF7F1A"),
            border_radius = 12,
            padding       = 15,
            margin        = 5,
            content       = Column(
                horizontal_alignment = "center",
                alignment            = "center",
                controls             = [
                    Text(veri["haber"], size=18, weight="bold", text_align="center", color=colors.CYAN_700, no_wrap=False),
                    Container(
                        expand        = True,
                        border_radius = 12,
                        image_fit     = ImageFit.FILL,
                        image_src     = veri["gorsel"]
                    ),
                    Text(veri["detay"], size=16, no_wrap=False)
                ]
            )
        )

    def haberleri_guncelle(self, guncelle:bool=False):
        if guncelle:
            self.__paneli_guncelle()

        if self.haberler:
            self.__sayfayi_guncelle()

    def __paneli_guncelle(self):
        self.panel.cikti_alani.color = colors.CYAN_700
        self.panel.cikti_alani.value = "Son dakika haberleri güncelleniyor.."
        self.panel.araniyor.visible  = True
        self.panel.update()
        self.sayfa.update()

        self.haberler = sondakika_haberleri()

        self.panel.araniyor.visible  = False
        self.panel.cikti_alani.color = colors.GREEN_700
        self.panel.cikti_alani.value = "Son dakika haberleri güncellendi!"
        self.panel.update()
        self.sayfa.update()

    def __sayfayi_guncelle(self):
        if self.haberler_grid.controls:
            self.haberler_grid.controls.clear()

        if len(self.haberler) > 20:
            bildirim(
                baslik = "NTV Son Dakika Haberleri",
                icerik = f"{len(self.haberler)} adet son dakika haberi bulundu!"
            )


        for haber in self.haberler:
            self.haberler_grid.controls.append(self.__haber_konteyner(haber))
            konsol.log(haber)

            if len(self.haberler) < 20:
                bildirim(
                    baslik = haber["haber"],
                    icerik = haber["detay"]
                )

        self.sayfa.update()


# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from ..Libs.NTV import sondakika_haberleri
from notifypy   import Notify
import os

ust_dizin_ver = lambda _path, n: os.sep.join(_path.split(os.sep)[:-n])

def dosya_ver(dosya_yolu:str, ust_dizin:int):
    return os.path.join(ust_dizin_ver(__file__, ust_dizin), dosya_yolu)

def bildirim(baslik:str, icerik:str):

    _bildirim = Notify()
    _bildirim._notification_application_name = "ntvHaber | @KekikAkademi"
    _bildirim._notification_icon             = dosya_ver("Assets/Logo.png", 2)

    if os.name == "nt":
        _bildirim.icon = dosya_ver("Assets/Logo.png", 2)

    _bildirim.title   = baslik
    _bildirim.message = icerik

    _bildirim.send(block=False)

from apscheduler.schedulers.background import BackgroundScheduler

zamanlayici = BackgroundScheduler(timezone="Europe/Istanbul", job_defaults={"misfire_grace_time": 15*60})


# Bu Araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from ..CLI    import konsol
from requests import get
from parsel   import Selector

RAMBASE = []

def detay_ver(veriler:list) -> list:
    haberler = []
    for haber in veriler:
        istek  = get(haber["link"])
        secici = Selector(istek.text)

        haber["detay"] = secici.xpath("normalize-space(//h2[@class='category-detail-sub-title'])").get().replace("SON DAKİKA HABERİ:", "").replace(" | Son depremler", "").replace("SON DAKİKA: ", "").replace("SON DAKİKA:", "").strip()
        haberler.append(haber)

    return haberler

def sondakika_haberleri() -> list:
    konsol.log("[yellow]sondakika_haberleri() fonksiyonu çalıştırıldı...[/]")

    global RAMBASE

    istek    = get("https://kolektifapi.kekikakademi.org/haber")
    haberler = istek.json()["veri"]

    detay_sor = []
    for haber in haberler:
        if haber["haber"] in RAMBASE:
            continue

        RAMBASE.append(haber["haber"])
        detay_sor.append(haber)

    if not detay_sor:
        return []

    return detay_ver(detay_sor)


# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from .CLI      import cikis_yap, hata_yakala

from flet      import FLET_APP, WEB_BROWSER
from flet      import app as flet
from flet.page import Page

import pystray
from PIL   import Image
from .Libs import dosya_ver

from .Layouts import KekikFlet, Panel, Haberler
from os       import name as sistem
from .Libs    import zamanlayici

ZAMANLA = False

def ana_sayfa(sayfa:Page):
    KekikFlet(sayfa, "ntvHaber | @KekikAkademi")

    panel = Panel(sayfa)
    sayfa.add(panel)

    haberler = Haberler(sayfa, panel)
    sayfa.add(haberler)

    global ZAMANLA
    if not ZAMANLA:
        zamanlayici.add_job(haberler.haberleri_guncelle, args=[True], trigger="interval", minutes=1, id="haberleri_guncelle")
        ZAMANLA = True


    def __goster():
        sayfa.window_minimized = False
        sayfa.update()

    def __gizle():
        sayfa.window_minimized = True
        sayfa.update()

    simge_durum = pystray.Icon(
        name  = sayfa.title,
        icon  = Image.open(dosya_ver("Assets/Logo.png", 2)),
        title = sayfa.title,
        menu  = pystray.Menu(
            pystray.MenuItem("Göster", __goster),
            pystray.MenuItem("Gizle", __gizle),            
            pystray.MenuItem("Kapat", sayfa.window_destroy)
        )
    )
    simge_durum.run()


# if __name__ == "__main__":
def basla():
    try:
        zamanlayici.start()
        flet(target=ana_sayfa, view=FLET_APP if sistem != "nt" else WEB_BROWSER, port=1927, assets_dir="Assets")
        cikis_yap(False)
    except Exception as hata:
        hata_yakala(hata)